@@ -19,6 +19,9 @@ def get_gridsearch(
     scoring="neg_mean_absolute_error",
     country_code_column=None,
     country_code=None,
+    holidays_days_before=0,
+    holidays_days_after=0,
+    holidays_bridge_days=False,
     sklearn_models=True,
     sklearn_models_optimize_for_horizon=False,
     autosarimax_models=False,
@@ -26,6 +29,7 @@ def get_gridsearch(
     prophet_models=False,
     tbats_models=False,
     exp_smooth_models=False,
+    theta_models=False,
     average_ensembles=False,
     stacking_ensembles=False,
     stacking_ensembles_train_horizon=10,
@@ -63,6 +67,20 @@ def get_gridsearch(
         Country code(s) in str (e.g. 'DE'). Used in holiday transformer.
         Only one of `country_code_column` or `country_code` can be set.
 
+    holidays_days_before : int
+        Number of days before the holiday which will be taken into account
+        (i.e. 2 means that new bool column will be created and will be True for 2 days before holidays,
+        otherwise False)
+
+    holidays_days_after : int
+        Number of days after the holiday which will be taken into account
+        (i.e. 2 means that new bool column will be created and will be True for 2 days after holidays,
+        otherwise False)
+
+    holidays_bridge_days : bool
+        Overlaping `holidays_days_before` and `holidays_days_after` feature which serves for modeling between
+        holidays working days
+
     sklearn_models : bool
         Whether to consider sklearn models
 
@@ -112,6 +130,7 @@ def get_gridsearch(
         [country_code_column] if isinstance(country_code_column, str) else country_code_column
     )
     country_codes = [country_code] if isinstance(country_code, str) else country_code
+
     # ensures only exogenous columns and country code column will be passed to model if provided
     # and columns names will be stored in TSColumnTransformer
     if exog_cols:
@@ -122,11 +141,33 @@ def get_gridsearch(
     # ensures holiday transformer is added to the pipeline if requested
     if country_codes:
         holiday = Pipeline(
-            [(f"holiday_{code}", HolidayTransformer(country_code=code)) for code in country_codes]
+            [
+                (
+                    f"holiday_{code}",
+                    HolidayTransformer(
+                        country_code=code,
+                        days_before=holidays_days_before,
+                        days_after=holidays_days_after,
+                        bridge_days=holidays_bridge_days,
+                    ),
+                )
+                for code in country_codes
+            ]
         )
     elif country_code_columns:
         holiday = Pipeline(
-            [(f"holiday_{col}", HolidayTransformer(country_code_column=col)) for col in country_code_columns]
+            [
+                (
+                    f"holiday_{col}",
+                    HolidayTransformer(
+                        country_code_column=col,
+                        days_before=holidays_days_before,
+                        days_after=holidays_days_after,
+                        bridge_days=holidays_bridge_days,
+                    ),
+                )
+                for col in country_code_columns
+            ]
         )
     else:
         holiday = "passthrough"
@@ -353,6 +394,20 @@ def get_gridsearch(
             }
         )
 
+    if theta_models:
+        from hcrystalball.wrappers import ThetaWrapper
+
+        grid_search.param_grid.append(
+            {
+                "model": [
+                    ThetaWrapper(
+                        clip_predictions_lower=clip_predictions_lower,
+                        clip_predictions_upper=clip_predictions_upper,
+                    )
+                ]
+            }
+        )
+
     if tbats_models:
         from hcrystalball.wrappers import TBATSWrapper
 
@@ -371,6 +426,7 @@ def get_gridsearch(
     if stacking_ensembles:
         from hcrystalball.ensemble import StackingEnsemble
         from hcrystalball.wrappers import ProphetWrapper
+        from hcrystalball.wrappers import ThetaWrapper
         from sklearn.ensemble import RandomForestRegressor
 
         grid_search.param_grid.append(
@@ -395,6 +451,10 @@ def get_gridsearch(
                             clip_predictions_upper=clip_predictions_upper,
                         ),
                         sklearn_model_pipeline,
+                        ThetaWrapper(
+                            clip_predictions_lower=clip_predictions_lower,
+                            clip_predictions_upper=clip_predictions_upper,
+                        ),
                     ],
                 ],
             }
@@ -402,6 +462,7 @@ def get_gridsearch(
     if average_ensembles:
         from hcrystalball.ensemble import SimpleEnsemble
         from hcrystalball.wrappers import ProphetWrapper
+        from hcrystalball.wrappers import ThetaWrapper
 
         grid_search.param_grid.append(
             {
@@ -419,6 +480,10 @@ def get_gridsearch(
                             clip_predictions_upper=clip_predictions_upper,
                         ),
                         sklearn_model_pipeline,
+                        ThetaWrapper(
+                            clip_predictions_lower=clip_predictions_lower,
+                            clip_predictions_upper=clip_predictions_upper,
+                        ),
                     ],
                 ],
             }
