@@ -41,6 +41,11 @@ class BaseSklearnWrapper(TSModelWrapper, metaclass=ABCMeta):
             y - numpy.ndarray
         """
         if y is not None:
+            if self.lags + horizon > len(self._y):
+                raise InsufficientDataLengthError(
+                    f"Sum of model lags ({self.lags}) and forecasting horizon ({horizon} "
+                    f"cannot be bigger than length of y ({len(y)})."
+                )
             y = self._y[self.lags + horizon - 1 :]
         X = self._add_lag_features(X, self._y, horizon)
         if X.filter(like="_holiday_").shape[1] > 0:
@@ -216,7 +221,7 @@ def _get_sklearn_wrapper(model_cls):
     """
 
     class SklearnWrapper(BaseSklearnWrapper):
-        """"Wrapper for regressors compatible with Sklearn-API.
+        """ "Wrapper for regressors compatible with Sklearn-API.
 
         This wrapper allows you use Sklearn-API regressors as autoregressive models
         for time series predictions. All model specific parameters will be passed to provided
